@@ -1,13 +1,9 @@
 package ParseUtil::Domain;
-
-## no critic
-our $VERSION = '2.42';
-$VERSION = eval $VERSION;
-## use critic
-
-use Carp;
+$ParseUtil::Domain::VERSION = '2.422';
+# VERSION
 
 use Modern::Perl;
+use Carp;
 use utf8::all;
 use autobox;
 use autobox::Core;
@@ -80,7 +76,7 @@ sub puny_convert : Export(:simple) {
 sub _find_zone {
     my $domain_segments = shift;
 
-    my $tld_regex = ParseUtil::Domain::ConfigData->config('tld_regex');
+    my $tld_regex = ParseUtil::Domain::ConfigData->tld_regex();
     ### Domain Segments: $domain_segments
     my $tld  = $domain_segments->pop;
     my $sld  = $domain_segments->pop;
@@ -223,6 +219,7 @@ sub _puny_decode {
 
 }
 
+1;
 __END__
 
 =encoding utf8
